FieldData

Struct FieldData 

pub struct FieldData<T> { /* private fields */ }
Data vector containing the data for a single field (column) of an agnes data store.

To support NA / missing values, a FieldData object is internally represented as a Vec of the appropriate type, along with a bit mask to denote valid / missing values.

Implementations

Source

impl<T> FieldData<T>

pub fn len(&self) -> usize

Returns the length of this data vector.

pub fn is_empty(&self) -> bool

Returns true if this field contains no values.

pub fn get(&self, index: usize) -> Option<Value<&T>>

Get the value at the given index. Returns None if index is out of bounds, or a Value enum.

pub fn take(&mut self, index: usize) -> Option<Value<T>>
where T: Default,

Take the value at the given index. Returns None if index is out of bounds, or a Value enum. Replaces the taken value with Value::Na.

pub fn as_vec(&self) -> Vec<Value<&T>>
where FieldData<T>: DataIndex<DType = T>,

Interpret FieldData as a Vec of Value objects.

pub fn from_boxed_slice(orig: Box<[T]>) -> Self

Create a new FieldData from a slice. Does not clone or reallocate the contained data (but does allocate the bit mask). Resulting FieldData struct will have no Value::Na values.

Source

impl<T> FieldData<T>

pub fn from_vec<U: Into<T>>(v: Vec<U>) -> FieldData<T>

Create a FieldData struct from a vector of non-NA values. Resulting FieldData struct will have no Value::Na values.

Source

impl<T> FieldData<T>
where T: Debug + Default,

pub fn push_val(&mut self, value: Value<T>)

Add a new value (or an indication of a missing one) to the data vector.

Source

impl<T> FieldData<T>
where T: Debug + Default + Clone,

pub fn push_ref(&mut self, value: Value<&T>)

Add a new value (passed by reference) to the data vector.

pub fn from_field_vec(v: Vec<Value<T>>) -> FieldData<T>

Create a FieldData struct from a vector of field values.