DataFrame

Struct DataFrame 

pub struct DataFrame<FrameFields, FramedStore> { /* private fields */ }
A data frame. A reference to the underlying data store along with record-based filtering and sorting details. FrameFields is a FieldLookupCons cons-list which maps a single label to one or more underlying store labels.

Implementations

Source

impl<FrameFields, FramedStore> DataFrame<FrameFields, FramedStore>
where FramedStore: NRows,

pub fn len(&self) -> usize

Returns length (number of rows) in this DataFrame.

pub fn is_empty(&self) -> bool

Returns whether or not this DataFrame is empty.