SortOrderUnstableComparator

Trait SortOrderUnstableComparator 

pub trait SortOrderUnstableComparator<F> {
    // Required method
    fn sort_order_unstable_by(&self, compare: F) -> Vec<usize>;
}
Trait providing function to compute and return the sorted permutation order. This sort is unstable (does not preserve original order of equal elements, but may be faster than the stable version).

Required Methods

fn sort_order_unstable_by(&self, compare: F) -> Vec<usize>

Returns the unstable sorted permutation order (Vec<usize>) using the specified comparator.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<DI, F> SortOrderUnstableComparator<F> for DI
where DI: DataIndex, F: FnMut(Value<&DI::DType>, Value<&DI::DType>) -> Ordering,