SelectFieldByLabel

Trait SelectFieldByLabel 

pub trait SelectFieldByLabel<Label> {
    type DType;
    type Output: DataIndex<DType = Self::DType>;

    // Required method
    fn select_field(&self) -> Self::Output;
}
Trait implemented by data structures to provide access to data for a single field.

Required Associated Types

type DType

Data type of accessed data.

type Output: DataIndex<DType = Self::DType>

The return type for the select_field method.

Required Methods

fn select_field(&self) -> Self::Output

Returns an object that provides DataIndex access to the data in the field specified by Label.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<FrameFields, FramedStore, Label> SelectFieldByLabel<Label> for DataFrame<FrameFields, FramedStore>
where FrameFields: SelectAndFrame<Label, FramedStore>,

Source

type DType = <FrameFields as SelectAndFrame<Label, FramedStore>>::DType

Source

type Output = Framed<<DataFrame<FrameFields, FramedStore> as SelectFieldByLabel<Label>>::DType, <FrameFields as SelectAndFrame<Label, FramedStore>>::Field>

Source

impl<Label, Fields> SelectFieldByLabel<Label> for DataStore<Fields>
where Fields: AssocStorage, Fields::Storage: LookupElemByLabel<Label>, ElemOf<Fields::Storage, Label>: Typed + Valued<Value = DataRef<TypeOfElemOf<Fields::Storage, Label>>>, TypeOfElemOf<Fields::Storage, Label>: Debug,

Source

impl<Labels, Frames, Label> SelectFieldByLabel<Label> for DataView<Labels, Frames>
where Frames: SelectFieldFromLabels<Labels, Label>,

Source

type DType = <Frames as SelectFieldFromLabels<Labels, Label>>::DType

Source

type Output = <Frames as SelectFieldFromLabels<Labels, Label>>::Output