Subview

Trait Subview 

pub trait Subview<LabelList> {
    type Output;

    // Required method
    fn subview(&self) -> Self::Output;
}
Trait for generating a subview of a DataView. LabelList is the fields to keep in the generated DataView.

Required Associated Types

type Output

Resulting subview DataView type.

Required Methods

fn subview(&self) -> Self::Output

Generate a new subview of this DataView, resulting in a newly created DataView object only containing the fields matching the labels in LabelList.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Labels, Frames, LabelList> Subview<LabelList> for DataView<Labels, Frames>
where Labels: FrameIndexList + HasLabels<LabelList> + LabelSubset<LabelList>, <Labels as LabelSubset<LabelList>>::Output: Reorder<LabelList>, Frames: Clone + SubsetClone<<Labels as FrameIndexList>::LabelList>,

Source

type Output = DataView<<<Labels as LabelSubset<LabelList>>::Output as Reorder<LabelList>>::Output, <Frames as SubsetClone<<Labels as FrameIndexList>::LabelList>>::Output>