pub struct FieldData<T> { /* private fields */ }Expand description
Data vector containing the data for a single field (column) of an agnes data store.
To support NA / missing values, a FieldData object is internally represented as a Vec of the
appropriate type, along with a bit mask to denote valid / missing values.
Implementations
Sourceimpl<T> FieldData<T>
impl<T> FieldData<T>
Sourcepub fn get(&self, index: usize) -> Option<Value<&T>>
pub fn get(&self, index: usize) -> Option<Value<&T>>
Get the value at the given index. Returns None if index is out of bounds, or a
Value enum.
Sourcepub fn take(&mut self, index: usize) -> Option<Value<T>>where
T: Default,
pub fn take(&mut self, index: usize) -> Option<Value<T>>where
T: Default,
Take the value at the given index. Returns None if index is out of bounds, or a
Value enum. Replaces the taken value with Value::Na.
Sourcepub fn from_boxed_slice(orig: Box<[T]>) -> Self
pub fn from_boxed_slice(orig: Box<[T]>) -> Self
Create a new FieldData from a slice. Does not clone or reallocate the contained data (but
does allocate the bit mask). Resulting FieldData struct will have no Value::Na values.