pub struct DataFrame<FrameFields, FramedStore> { /* private fields */ }Expand description
A data frame. A reference to the underlying data store along with record-based filtering and
sorting details. FrameFields is a FieldLookupCons cons-list which
maps a single label to one or more underlying store labels.
Implementations